@@ -45,6 +45,7 @@ class AbstractRunner(ABC):
         self.ivp_allocation = True
         self.mvp_allocation = True
         self.hrp_allocation = True
+        self.hrc_allocation = True
         self.mdp_allocation = True
 
     @abstractmethod
@@ -200,6 +201,28 @@ class SimpleEnsemblingRunner(AbstractRunner):
             saver.saveResults('hrp_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
 
 
+        check_hrc_existence = saver.checkRunExistence('hrc_'+savingKey)
+        if self.hrc_allocation and not check_hrc_existence:
+            print('computing hrp weights')
+            df_res = df.copy()
+            portfolio, weight_mat = allocation.rolling_allocation(
+                allocation.HRC,
+                df_res,
+                n=n,
+                s=s,
+                ret=True,
+                drift=True,
+                method='centroid',
+                metric='mse',
+                up_bound=up_bound,
+                low_bound=low_bound,
+                filtering_threshold=0.9
+            )
+            df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
+            weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
+            portfolio = np.cumprod(np.prod(df_ret * weight_normalized.values + 1, axis=1))
+            saver.saveResults('hrp_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
+
         check_mdp_existence = saver.checkRunExistence('mdp_'+savingKey)
         if self.mdp_allocation and not check_mdp_existence:
             print('computing mdp weights')
